@@ -35,6 +35,7 @@ from .type_defs import (
     CreateRecipeJobResponseTypeDef,
     CreateRecipeResponseTypeDef,
     CreateScheduleResponseTypeDef,
+    DatabaseOutputTypeDef,
     DataCatalogOutputTypeDef,
     DeleteDatasetResponseTypeDef,
     DeleteJobResponseTypeDef,
@@ -60,6 +61,7 @@ from .type_defs import (
     ListTagsForResourceResponseTypeDef,
     OutputTypeDef,
     PathOptionsTypeDef,
+    ProfileConfigurationTypeDef,
     PublishRecipeResponseTypeDef,
     RecipeReferenceTypeDef,
     RecipeStepTypeDef,
@@ -107,7 +109,7 @@ class Exceptions:
 
 class GlueDataBrewClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html)
     """
 
@@ -125,7 +127,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes one or more versions of a recipe at a time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#batch_delete_recipe_version)
         """
 
@@ -133,7 +135,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#can_paginate)
         """
 
@@ -150,7 +152,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Creates a new DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_dataset)
         """
 
@@ -166,6 +168,7 @@ class GlueDataBrewClient(BaseClient):
         LogSubscription: LogSubscriptionType = None,
         MaxCapacity: int = None,
         MaxRetries: int = None,
+        Configuration: "ProfileConfigurationTypeDef" = None,
         Tags: Dict[str, str] = None,
         Timeout: int = None,
         JobSample: "JobSampleTypeDef" = None
@@ -173,7 +176,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Creates a new job to analyze a dataset and create its data profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_profile_job)
         """
 
@@ -190,7 +193,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Creates a new DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.create_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.create_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_project)
         """
 
@@ -205,7 +208,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Creates a new DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_recipe)
         """
 
@@ -222,6 +225,7 @@ class GlueDataBrewClient(BaseClient):
         MaxRetries: int = None,
         Outputs: List["OutputTypeDef"] = None,
         DataCatalogOutputs: List["DataCatalogOutputTypeDef"] = None,
+        DatabaseOutputs: List["DatabaseOutputTypeDef"] = None,
         ProjectName: str = None,
         RecipeReference: "RecipeReferenceTypeDef" = None,
         Tags: Dict[str, str] = None,
@@ -233,7 +237,7 @@ class GlueDataBrewClient(BaseClient):
         <https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateRecipeJob>`_
         **Request Syntax** response = client.create_recipe_job( DatasetName...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_recipe_job)
         """
 
@@ -248,7 +252,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Creates a new schedule for one or more DataBrew jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_schedule)
         """
 
@@ -256,7 +260,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes a dataset from DataBrew.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_dataset)
         """
 
@@ -264,7 +268,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes the specified DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_job)
         """
 
@@ -272,7 +276,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes an existing DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_project)
         """
 
@@ -282,7 +286,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes a single version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_recipe_version)
         """
 
@@ -290,7 +294,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes the specified DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_schedule)
         """
 
@@ -298,7 +302,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_dataset)
         """
 
@@ -306,7 +310,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_job)
         """
 
@@ -314,7 +318,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Represents one run of a DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.describe_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.describe_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_job_run)
         """
 
@@ -322,7 +326,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_project)
         """
 
@@ -333,7 +337,7 @@ class GlueDataBrewClient(BaseClient):
         Returns the definition of a specific DataBrew recipe corresponding to a
         particular version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_recipe)
         """
 
@@ -341,7 +345,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_schedule)
         """
 
@@ -355,7 +359,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#generate_presigned_url)
         """
 
@@ -365,7 +369,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew datasets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_datasets)
         """
 
@@ -375,7 +379,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the previous runs of a particular DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_job_runs)
         """
 
@@ -390,7 +394,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew jobs that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_jobs)
         """
 
@@ -400,7 +404,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew projects that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_projects)
         """
 
@@ -411,7 +415,7 @@ class GlueDataBrewClient(BaseClient):
         Lists the versions of a particular DataBrew recipe, except for `LATEST_WORKING`
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_recipe_versions)
         """
 
@@ -421,7 +425,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew recipes that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_recipes)
         """
 
@@ -431,7 +435,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists the DataBrew schedules that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_schedules)
         """
 
@@ -439,7 +443,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all the tags for a DataBrew resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_tags_for_resource)
         """
 
@@ -447,7 +451,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Publishes a new version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#publish_recipe)
         """
 
@@ -465,7 +469,7 @@ class GlueDataBrewClient(BaseClient):
         Performs a recipe step within an interactive DataBrew session that's currently
         open.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#send_project_session_action)
         """
 
@@ -473,7 +477,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Runs a DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#start_job_run)
         """
 
@@ -484,7 +488,7 @@ class GlueDataBrewClient(BaseClient):
         Creates an interactive session, enabling you to manipulate data in a DataBrew
         project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#start_project_session)
         """
 
@@ -492,7 +496,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Stops a particular run of a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#stop_job_run)
         """
 
@@ -501,7 +505,7 @@ class GlueDataBrewClient(BaseClient):
         Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe,
         job, or schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#tag_resource)
         """
 
@@ -509,7 +513,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Removes metadata tags from a DataBrew resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#untag_resource)
         """
 
@@ -525,7 +529,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_dataset)
         """
 
@@ -535,6 +539,7 @@ class GlueDataBrewClient(BaseClient):
         Name: str,
         OutputLocation: "S3LocationTypeDef",
         RoleArn: str,
+        Configuration: "ProfileConfigurationTypeDef" = None,
         EncryptionKeyArn: str = None,
         EncryptionMode: EncryptionModeType = None,
         LogSubscription: LogSubscriptionType = None,
@@ -546,7 +551,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing profile job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_profile_job)
         """
 
@@ -556,7 +561,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.update_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.update_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_project)
         """
 
@@ -566,7 +571,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of the `LATEST_WORKING` version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_recipe)
         """
 
@@ -582,12 +587,13 @@ class GlueDataBrewClient(BaseClient):
         MaxRetries: int = None,
         Outputs: List["OutputTypeDef"] = None,
         DataCatalogOutputs: List["DataCatalogOutputTypeDef"] = None,
+        DatabaseOutputs: List["DatabaseOutputTypeDef"] = None,
         Timeout: int = None
     ) -> UpdateRecipeJobResponseTypeDef:
         """
         Modifies the definition of an existing DataBrew recipe job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_recipe_job)
         """
 
@@ -597,35 +603,35 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_schedule)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listdatasetspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobrunspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listprojectspaginator)
         """
 
@@ -634,20 +640,20 @@ class GlueDataBrewClient(BaseClient):
         self, operation_name: Literal["list_recipe_versions"]
     ) -> ListRecipeVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipeversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_recipes"]) -> ListRecipesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_schedules"]) -> ListSchedulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.6/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listschedulespaginator)
         """
